==> dl.php?src=linea21_1_7.zip: linea21/languages/fr/lang_user.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['user']['section'] = "utilisateurs";

/*	nommage des modules
 *  	*/
$lang['user']['name']='utilisateur';
$lang['user']['confirm_add'] = "Ajout de l'utilisateur réalisé avec succès\n";
$lang['user']['confirm_mod'] = "Modification de l'utilisateur réalisée avec succès\n";
$lang['user']['confirm_modpass'] = "Génération d'un nouveau mot de passe pour l'utilisateur réalisé avec succès\n";
$lang['user']['confirm_sup'] ="Suppression de l'utilisateur réalisée avec succès\n";
$lang['user']['confirm_changetype']="Modification du type d'utilisateur réalisée avec succès\n";
$lang['user']['confirm_public'] = 'Création de votre compte réalisée avec succès. Votre mot de passe vous a été transmis par email.';
$lang['user']['confirm_delavatar'] = "Suppression de l'avatar réalisée avec succès";

/*	nommage rubrique module
 *  	*/
$lang['user']['add']= 'Ajout d\'un '.$lang['user']['name'];
$lang['user']['mod']= 'Modification d\'un '.$lang['user']['name'];
$lang['user']['sup']= 'Suppression de l\''.$lang['user']['name'];
$lang['user']['det']= 'Détails de l\''.$lang['user']['name'];
$lang['user']['list']= 'Consultation des utilisateurs';


$lang['user']['h1_public_comment_insc']='L\'inscription vous permet de participer à nos différents groupes de travail. Suite à votre enregistrement, vous recevrez par email, un mot de passe que vous pourrez changer ultérieurement';
$lang['user']['h1_public_comment_auth']='Authentifiez vous afin d\'accéder aux groupes de travail et d\'avoir accès à vos informations personnelles en modification.';
$lang['user']['h1_public_comment']='Votre profil utilisateur est à votre disposition pour vous décrire et permet ainsi à la communauté de mieux vous connaitre.';

/*	nommage public
 *  	*/

$lang['user']['p_mod']= 'Modification de votre profil utilisateur';
$lang['user']['forgot_pass']= 'Mot de passe oublié';
$lang['user']['p_mod_table_summary']='Formulaire de modification de votre profil utilisateur';
$lang['user']['info_mail']= 'Si vous changez votre email, un nouveau mot de passe vous sera attribué dans un mail de confirmation à votre nouvelle adresse.';
$lang['user']['info_password']=  'Remplissez les champs suivants UNIQUEMENT si vous souhaitez changer de mot de passe !';
$lang['user']['p_new_password']=  'Nouveau mot de passe';
$lang['user']['p_new_password_confirm']=  'mot de passe (confirmation) ';
$lang['user']['new_password_confirmation']=  'Un nouveau mot de passe vous a été attribué par mail.';
$lang['user']['p_confirm_mod'] = "Modification de votre profil réalisée avec succès";
$lang['user']['p_confirm_back'] = "Cliquer ici pour revenir à la page d'accueil";
$lang['user']['info_inscription'] = "Vous n'êtes pas encore inscrit ?";
$lang['user']['info_inscription2'] = "Cliquez ici pour créer votre compte";
$lang['user']['info_inscription3'] = "L'inscription vous permet de participer à nos différents groupes de travail.";
//$lang['user']['info_inscription4'] = "Suite à votre enregistrement, vous recevrez par email, un mot de passe que vous pourrez changer ultérieurement";

/*	password strength javascript test
 *  	*/
$lang['password_strength']['too_short']='Entrez au moins %s carcatères';
$lang['password_strength']['novalue']='Pas de valeur';
$lang['password_strength']['weak']='Faible';
$lang['password_strength']['average']='Moyen';
$lang['password_strength']['strong']='Fort';
$lang['password_strength']['secure']='Sécurisé';

/*	nommage rubrique add / mod /det
 *  	*/
$lang['user']['add_title']='Saisie des informations du nouvel '.$lang['user']['name'];
$lang['user']['mod_title']='Modification des informations de l\''.$lang['user']['name'];


/*	check integrité des données
 *  	*/
$lang['user']['login_used'] = 'Ce login est déjà utilisé. Veuillez en choisir un autre';
$lang['user']['login_tooshort'] = 'Votre login n\'est pas assez long (minimum 5 caractères).';
$lang['user']['login_toolong'] = 'Votre login est trop long (maximum 50 caractères).';
$lang['user']['login_prohibited'] = 'Votre login comporte des caractères non autorisés.';
$lang['user']['pass_tooshort'] = 'Votre mot de passe n\'est pas assez long (minimum %s caractères).';
$lang['user']['pass_toolong'] = 'Votre mot de passe est trop long (maximum 15 caractères).';
$lang['user']['pass_not_same'] = 'Les valeurs rentrées pour le nouveau mot de passe ne sont pas identiques.';
$lang['user']['invalid_mail'] = 'L\'email saisi est invalide';


/*	nommage élément rubrique
 *  	*/
$lang['user']['type']='Type d\''.$lang['user']['name'];
$lang['user']['type_simple']=$lang['user']['name'].' simple';
$lang['user']['type_privilege']=$lang['user']['name'].' privilegié';
$lang['user']['type_admin']='administrateur';
$lang['user']['pseudo']='pseudonyme (login)';
$lang['user']['email']='email '.$lang['user']['name'];
$lang['user']['workgroups']='participant aux groupes de travail';
$lang['user']['profile']='Profil de l\''.$lang['user']['name'];



$lang['user']['rights']='Droits par modules';
$lang['user']['set_rights']='Attributions de droits par modules';
$lang['user']['update_rights']='Modifications de droits par modules';
$lang['user']['norights']='aucun droit';
$lang['user']['redactorrights']='rédacteur';
$lang['user']['animatorrights']='animateur';
$lang['user']['adminrights']='administrateur';
$lang['user']['managerrights']='gestionnaire';
$lang['user']['login']='login';
$lang['user']['previous_logins']='Ancien(s) login(s)';
$lang['user']['password']='mot de passe';
$lang['user']['email']='email';
$lang['user']['first_name']='prénom';
$lang['user']['last_name']='nom';
$lang['user']['groupe']='groupe';
$lang['user']['date_record']='date d\'enregistrement';
$lang['user']['actions']='actions';


$lang['user']['email_display']='Email Public';
$lang['user']['city']='Ville';
$lang['user']['birthdate']='Date de naissance';
$lang['user']['leisures']='Loisirs';
$lang['user']['job']='Occupations/métiers';
$lang['user']['avatar']='Avatar';
$lang['user']['current_avatar']='Avatar actuel';
$lang['user']['delete_avatar']='Supprimer l\'avatar actuel';
$lang['user']['quotation']='Citation';
$lang['user']['latest_con']='Dernière connexion';
$lang['user']['signature']='Signature';
// $lang['user']['comment']="Commentaire lié à cet ".$lang['user']['name'];


$lang['user']['preferences']='Mes préférences';
$lang['user']['my_workgroups']='Mes groupes de travail';
$lang['user']['workgroups_notification']='Un système de notification permet d\'être tenu à jour de l\'activité des groupes de travail auxquels vous participez. Vous avez la possibilité de configurer vos options de notification pour chacun d\'entre eux.';
$lang['user']['notify_file']='Notification - Nouveau fichier';
$lang['user']['notify_topic']='Notification - Nouvelle discussion';
$lang['user']['notify_post']='Notification - Nouveau message';
$lang['user']['workgroups_label']='Groupe de travail';
$lang['user']['notify_changes_success']='Modification des préférences de notifications réalisée avec succès.';
$lang['user']['change_login']='changer de login';
$lang['user']['change_login_desc']='%s changement effectué(s) sur %s autorisé(s)';
$lang['user']['change_login_limit_done']='changement(s) effectué(s) : %s/%s';
$lang['user']['change_login_allowed']='Vous êtes autorisé à changer votre login';
$lang['user']['change_login_limit_reached']='Vous n\'êtes pas autorisé à changer votre login';
$lang['user']['newsletter_subscription_info']='En créant un compte sur notre site, vous acceptez l\'inscription automatique à notre newsletter. Vous pourrez, à tout moment, vous désinscrire en utilisant le formulaire idoine.';
$lang['user']['newsletter_law_reference']='Conformément à la loi « informatique et libertés » du 6 janvier 1978 modifiée en 2004, vous bénéficiez d’un droit d’accès et de rectification aux informations qui vous concernent.';

/*	nommage quickbox
 *  	*/
$lang['user']['qb_titleadd']=' derniers ajouts effectués';
$lang['user']['qb_titlemod']=' dernières modifications effectuées';
$lang['user']['qb_titlesup']=' dernières suppressions effectuées';


$lang['user']['ldap_password']='votre mot de passe habituel';
$lang['user']['new_password']='Attribuer un nouveau mot de passe';
$lang['user']['2ADMIN_USER']='Faire de cet utilisateur un administrateur';
$lang['user']['2SIMPLE_USER']='Faire de cet utilisateur un utilisateur standard';

/*	divers
 *  	*/
$lang['user']['selectgroup']='-- par groupe --';
$lang['user']['alphabetical']=' [A-Z] ';
$lang['user']['nb_total']='utilisateurs sont inscrits dans la base de données.';
$lang['user']['statut_filter']='Afficher par statut';
$lang['user']['all']='Afficher la liste complete';
$lang['user']['noresult']='Aucun utilisateur ne correspond à ce critère de sélection ';


/*	messages
 *  	*/
$lang['user']['admin_type_info']='L\'utilisateur courant est un administrateur de l\'application. Ses droits ne sont pas révisables avant modification du type d\'utilisateur';



/*	rubrique d'aide

*  	*/
$lang['user']['help_add1']='Pour ajouter un utilisateur, vous devez saisir son login et son email dans le formulaire ci-dessus.';
$lang['user']['help_add2']='Si vous souhaitez créer un utilisateur de type \'privilegié\', vous devez alors lui attribuer des droits sur les différents modules';
$lang['user']['help_add3']='Après avoir validé le formulaire d\'ajout, vérifiez les informations entrées dans le récapitulatif';
$lang['user']['help_add4']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';
$lang['user']['help_add5']='Un mot de passe généré aléatoirement sera automatiquement envoyé au nouvel utilisateur lors de la création';


$lang['user']['help_list1']='Pour afficher le détail d\'un utilisateur, cliquez sur le login de celui-ci';
$lang['user']['help_list2']='Vous pouvez supprimer un utilisateur en cliquant sur l\'icône de suppression qui lui est associée';
$lang['user']['help_list3']='Vous pouvez modifier un utilisateur en cliquant sur l\'icône de modification qui lui est associée';
$lang['user']['help_list4']='Vous pouvez utiliser les filtres \'par groupe\' pour afficher uniquement le type d\'utilisateur desiré';
$lang['user']['help_list5']='Vous pouvez utiliser le filtre \'alphabétique\' afin de restreindre l\'affichage des utilisateurs';
$lang['user']['help_list6']='Pour ajouter un utilisateur, cliquez sur le lien \'ajouter un utilisateur\' dans la barre de titre';
$lang['user']['help_list7']='Vous pouvez faire une recherche avancée à tout moment en cliquant sur \'recherche\'';


$lang['user']['help_mod1']='Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus';
$lang['user']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif';
$lang['user']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['user']['help_det1']='Vous pouvez supprimer cet utilisateur en cliquant sur l\'icône de suppression qui lui est associée';
$lang['user']['help_det2']='Vous pouvez modifier les informations concernant cet utilisateur en cliquant sur l\'icône de modification qui lui est associée';

$lang['user']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de l\'utilisateur en cours, cliquez sur \'Annuler\'.';



/*	mail
 **/
$lang['user']['mail_add_subject']='création de votre compte utilisateur';
$lang['user']['mail_add_body1']='Votre compte a été créé avec succès.';
$lang['user']['mail_add_body2']='Vous pouvez dès a présent vous logger. Nous vous rappelons vos paramètres de connexion.';

$lang['user']['mail_changemail_subject']='changement du couple email/mot de passe';
$lang['user']['mail_changemail_body1']='Vous recevez cet email car vous avez changé votre adresse email. Par mesure de sécurité, nous vous attribuons un nouveau mot de passe.';
$lang['user']['mail_changemail_body2']='Notez qu\'il demeure possible pour vous de changer de mot de passe depuis la gestion de votre \'profil utilisateur\'.';

$lang['user']['mail_changelogin_subject']='Nouveau login';
$lang['user']['mail_changelogin_body1']='Vous recevez cet email car vous avez changé votre login ou un nouveau login vous a été attribué. Votre nouveau login est : ';

$lang['user']['mail_changepass_subject']='Nouveau mot de passe';
$lang['user']['mail_changepass_body1']='Vous recevez cet email car vous avez changé votre mot de passe ou un nouveau mot de passe vous a été attribué.';
$lang['user']['mail_changepass_body2']='Notez qu\'il demeure possible pour vous de changer de mot de passe depuis la gestion de votre \'profil utilisateur\'.';

$lang['user']['mail_forgotpass_subject']='Mot de passe oublié';
$lang['user']['mail_forgotpass_body1']='Vous avez fait une demande de nouveau mot de passe. Afin de procéder à l\'envoi, veuillez cliquer le lien suivant (ou le copier-coller dans votre navigateur).' ;
$lang['user']['mail_forgotpass_body2']='Si vous n\'êtes pas à l\'origine de cette demande, ignorez ce mail.';
?>

==> dl.php?src=linea21_1_8.zip: linea21/languages/fr/lang_user.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['user']['section'] = "utilisateurs";

/*	nommage des modules
 *  	*/
$lang['user']['name']='utilisateur';
$lang['user']['confirm_add'] = "Ajout de l'utilisateur réalisé avec succès\n";
$lang['user']['confirm_mod'] = "Modification de l'utilisateur réalisée avec succès\n";
$lang['user']['confirm_modpass'] = "Génération d'un nouveau mot de passe pour l'utilisateur réalisé avec succès\n";
$lang['user']['confirm_sup'] ="Suppression de l'utilisateur réalisée avec succès\n";
$lang['user']['confirm_changetype']="Modification du type d'utilisateur réalisée avec succès\n";
$lang['user']['confirm_public'] = 'Création de votre compte réalisée avec succès. Votre mot de passe vous a été transmis par email.';
$lang['user']['confirm_delavatar'] = "Suppression de l'avatar réalisée avec succès";

/*	nommage rubrique module
 *  	*/
$lang['user']['add']= 'Ajout d\'un '.$lang['user']['name'];
$lang['user']['mod']= 'Modification d\'un '.$lang['user']['name'];
$lang['user']['sup']= 'Suppression de l\''.$lang['user']['name'];
$lang['user']['det']= 'Détails de l\''.$lang['user']['name'];
$lang['user']['list']= 'Consultation des utilisateurs';


$lang['user']['h1_public_comment_insc']='L\'inscription vous permet de participer à nos différents groupes de travail. Suite à votre enregistrement, vous recevrez par email, un mot de passe que vous pourrez changer ultérieurement';
$lang['user']['h1_public_comment_auth']='Authentifiez vous afin d\'accéder aux groupes de travail et d\'avoir accès à vos informations personnelles.';
$lang['user']['h1_public_comment']='Votre profil utilisateur est à votre disposition pour vous décrire et permet ainsi à la communauté de mieux vous connaitre.';

/*	nommage public
 *  	*/

$lang['user']['p_mod']= 'Modification de votre profil utilisateur';
$lang['user']['forgot_pass']= 'Mot de passe oublié';
$lang['user']['p_mod_table_summary']='Formulaire de modification de votre profil utilisateur';
$lang['user']['info_mail']= 'Si vous changez votre email, un nouveau mot de passe vous sera attribué dans un mail de confirmation à votre nouvelle adresse.';
$lang['user']['info_password']=  'Remplissez les champs suivants UNIQUEMENT si vous souhaitez changer de mot de passe !';
$lang['user']['p_new_password']=  'Nouveau mot de passe';
$lang['user']['p_new_password_confirm']=  'mot de passe (confirmation) ';
$lang['user']['new_password_confirmation']=  'Un nouveau mot de passe vous a été attribué par mail.';
$lang['user']['p_confirm_mod'] = "Modification de votre profil réalisée avec succès";
$lang['user']['p_confirm_back'] = "Cliquer ici pour revenir à la page d'accueil";
$lang['user']['info_inscription'] = "Vous n'êtes pas encore inscrit ?";
$lang['user']['info_inscription2'] = "Cliquez ici pour créer votre compte";
$lang['user']['info_inscription3'] = "L'inscription vous permet de participer à nos différents groupes de travail.";
//$lang['user']['info_inscription4'] = "Suite à votre enregistrement, vous recevrez par email, un mot de passe que vous pourrez changer ultérieurement";

/*	password strength javascript test
 *  	*/
$lang['password_strength']['too_short']='Entrez au moins %s carcatères';
$lang['password_strength']['novalue']='Pas de valeur';
$lang['password_strength']['weak']='Faible';
$lang['password_strength']['average']='Moyen';
$lang['password_strength']['strong']='Fort';
$lang['password_strength']['secure']='Sécurisé';

/*	nommage rubrique add / mod /det
 *  	*/
$lang['user']['add_title']='Saisie des informations du nouvel '.$lang['user']['name'];
$lang['user']['mod_title']='Modification des informations de l\''.$lang['user']['name'];


/*	check integrité des données
 *  	*/
$lang['user']['login_used'] = 'Ce login est déjà utilisé. Veuillez en choisir un autre';
$lang['user']['login_tooshort'] = 'Votre login n\'est pas assez long (minimum 5 caractères).';
$lang['user']['login_toolong'] = 'Votre login est trop long (maximum 50 caractères).';
$lang['user']['login_prohibited'] = 'Votre login comporte des caractères non autorisés.';
$lang['user']['pass_tooshort'] = 'Votre mot de passe n\'est pas assez long (minimum %s caractères).';
$lang['user']['pass_toolong'] = 'Votre mot de passe est trop long (maximum 100 caractères).';
$lang['user']['pass_not_same'] = 'Les valeurs rentrées pour le nouveau mot de passe ne sont pas identiques.';
$lang['user']['invalid_mail'] = 'L\'email saisi est invalide';


/*	nommage élément rubrique
 *  	*/
$lang['user']['type']='Type d\''.$lang['user']['name'];
$lang['user']['type_simple']=$lang['user']['name'].' simple';
$lang['user']['type_privilege']=$lang['user']['name'].' privilegié';
$lang['user']['type_admin']='administrateur';
$lang['user']['pseudo']='pseudonyme (login)';
$lang['user']['email']='email '.$lang['user']['name'];
$lang['user']['workgroups']='participant aux groupes de travail';
$lang['user']['profile']='Profil de l\''.$lang['user']['name'];



$lang['user']['rights']='Droits par modules';
$lang['user']['set_rights']='Attributions de droits par modules';
$lang['user']['update_rights']='Modifications de droits par modules';
$lang['user']['norights']='aucun droit';
$lang['user']['redactorrights']='rédacteur';
$lang['user']['animatorrights']='animateur';
$lang['user']['adminrights']='administrateur';
$lang['user']['managerrights']='gestionnaire';
$lang['user']['login']='login';
$lang['user']['previous_logins']='Ancien(s) login(s)';
$lang['user']['password']='mot de passe';
$lang['user']['email']='email';
$lang['user']['first_name']='prénom';
$lang['user']['last_name']='nom';
$lang['user']['groupe']='groupe';
$lang['user']['date_record']='date d\'enregistrement';
$lang['user']['actions']='actions';


$lang['user']['email_display']='Email Public';
$lang['user']['city']='Ville';
$lang['user']['birthdate']='Date de naissance';
$lang['user']['leisures']='Loisirs';
$lang['user']['job']='Occupations/métiers';
$lang['user']['avatar']='Avatar';
$lang['user']['current_avatar']='Avatar actuel';
$lang['user']['delete_avatar']='Supprimer l\'avatar actuel';
$lang['user']['quotation']='Citation';
$lang['user']['latest_con']='Dernière connexion';
$lang['user']['signature']='Signature';
// $lang['user']['comment']="Commentaire lié à cet ".$lang['user']['name'];


$lang['user']['preferences']='Mes préférences';
$lang['user']['my_workgroups']='Mes groupes de travail';
$lang['user']['workgroups_notification']='Un système de notification permet d\'être tenu à jour de l\'activité des groupes de travail auxquels vous participez. Vous avez la possibilité de configurer vos options de notification pour chacun d\'entre eux.';
$lang['user']['notify_file']='Notification - Nouveau fichier';
$lang['user']['notify_topic']='Notification - Nouvelle discussion';
$lang['user']['notify_post']='Notification - Nouveau message';
$lang['user']['workgroups_label']='Groupe de travail';
$lang['user']['notify_changes_success']='Modification des préférences de notifications réalisée avec succès.';
$lang['user']['change_login']='changer de login';
$lang['user']['change_login_desc']='%s changement effectué(s) sur %s autorisé(s)';
$lang['user']['change_login_limit_done']='changement(s) effectué(s) : %s/%s';
$lang['user']['change_login_allowed']='Vous êtes autorisé à changer votre login';
$lang['user']['change_login_limit_reached']='Vous n\'êtes pas autorisé à changer votre login';
$lang['user']['newsletter_subscription_info']='En créant un compte sur notre site, vous acceptez l\'inscription automatique à notre newsletter. Vous pourrez, à tout moment, vous désinscrire en utilisant le formulaire idoine.';
$lang['user']['newsletter_law_reference']='Conformément à la loi « informatique et libertés » du 6 janvier 1978 modifiée en 2004, vous bénéficiez d’un droit d’accès et de rectification aux informations qui vous concernent.';

/*	nommage quickbox
 *  	*/
$lang['user']['qb_titleadd']=' derniers ajouts effectués';
$lang['user']['qb_titlemod']=' dernières modifications effectuées';
$lang['user']['qb_titlesup']=' dernières suppressions effectuées';


$lang['user']['ldap_password']='votre mot de passe habituel';
$lang['user']['new_password']='Attribuer un nouveau mot de passe';
$lang['user']['2ADMIN_USER']='Faire de cet utilisateur un administrateur';
$lang['user']['2SIMPLE_USER']='Faire de cet utilisateur un utilisateur standard';

/*	divers
 *  	*/
$lang['user']['selectgroup']='-- par groupe --';
$lang['user']['alphabetical']=' [A-Z] ';
$lang['user']['nb_total']='utilisateurs sont inscrits dans la base de données.';
$lang['user']['statut_filter']='Afficher par statut';
$lang['user']['all']='Afficher la liste complete';
$lang['user']['noresult']='Aucun utilisateur ne correspond à ce critère de sélection ';


/*	messages
 *  	*/
$lang['user']['admin_type_info']='L\'utilisateur courant est un administrateur de l\'application. Ses droits ne sont pas révisables avant modification du type d\'utilisateur';



/*	rubrique d'aide

*  	*/
$lang['user']['help_add1']='Pour ajouter un utilisateur, vous devez saisir son login et son email dans le formulaire ci-dessus.';
$lang['user']['help_add2']='Si vous souhaitez créer un utilisateur de type \'privilegié\', vous devez alors lui attribuer des droits sur les différents modules';
$lang['user']['help_add3']='Après avoir validé le formulaire d\'ajout, vérifiez les informations entrées dans le récapitulatif';
$lang['user']['help_add4']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';
$lang['user']['help_add5']='Un mot de passe généré aléatoirement sera automatiquement envoyé au nouvel utilisateur lors de la création';


$lang['user']['help_list1']='Pour afficher le détail d\'un utilisateur, cliquez sur le login de celui-ci';
$lang['user']['help_list2']='Vous pouvez supprimer un utilisateur en cliquant sur l\'icône de suppression qui lui est associée';
$lang['user']['help_list3']='Vous pouvez modifier un utilisateur en cliquant sur l\'icône de modification qui lui est associée';
$lang['user']['help_list4']='Vous pouvez utiliser les filtres \'par groupe\' pour afficher uniquement le type d\'utilisateur desiré';
$lang['user']['help_list5']='Vous pouvez utiliser le filtre \'alphabétique\' afin de restreindre l\'affichage des utilisateurs';
$lang['user']['help_list6']='Pour ajouter un utilisateur, cliquez sur le lien \'ajouter un utilisateur\' dans la barre de titre';
$lang['user']['help_list7']='Vous pouvez faire une recherche avancée à tout moment en cliquant sur \'recherche\'';


$lang['user']['help_mod1']='Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus';
$lang['user']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif';
$lang['user']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['user']['help_det1']='Vous pouvez supprimer cet utilisateur en cliquant sur l\'icône de suppression qui lui est associée';
$lang['user']['help_det2']='Vous pouvez modifier les informations concernant cet utilisateur en cliquant sur l\'icône de modification qui lui est associée';

$lang['user']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de l\'utilisateur en cours, cliquez sur \'Annuler\'.';



/*	mail
 **/
$lang['user']['mail_add_subject']='création de votre compte utilisateur';
$lang['user']['mail_add_body1']='Votre compte a été créé avec succès.';
$lang['user']['mail_add_body2']='Vous pouvez dès a présent vous logger. Nous vous rappelons vos paramètres de connexion.';

$lang['user']['mail_changemail_subject']='changement du couple email/mot de passe';
$lang['user']['mail_changemail_body1']='Vous recevez cet email car vous avez changé votre adresse email. Par mesure de sécurité, nous vous attribuons un nouveau mot de passe.';
$lang['user']['mail_changemail_body2']='Notez qu\'il demeure possible pour vous de changer de mot de passe depuis la gestion de votre \'profil utilisateur\'.';

$lang['user']['mail_changelogin_subject']='Nouveau login';
$lang['user']['mail_changelogin_body1']='Vous recevez cet email car vous avez changé votre login ou un nouveau login vous a été attribué. Votre nouveau login est : ';

$lang['user']['mail_changepass_subject']='Nouveau mot de passe';
$lang['user']['mail_changepass_body1']='Vous recevez cet email car vous avez changé votre mot de passe ou un nouveau mot de passe vous a été attribué.';
$lang['user']['mail_changepass_body2']='Notez qu\'il demeure possible pour vous de changer de mot de passe depuis la gestion de votre \'profil utilisateur\'.';

$lang['user']['mail_forgotpass_subject']='Mot de passe oublié';
$lang['user']['mail_forgotpass_body1']='Vous avez fait une demande de nouveau mot de passe. Afin de procéder à l\'envoi, veuillez cliquer le lien suivant (ou le copier-coller dans votre navigateur).' ;
$lang['user']['mail_forgotpass_body2']='Si vous n\'êtes pas à l\'origine de cette demande, ignorez ce mail.';
?>
